#
# frontier_awstats :   RPM Spec file for frontier_awstats conf files
# Author: Flavia Donno <Flavia.Donno@cern.ch>
# Creation Date: 28 Jul 2010
#

Summary: Awstats config files for Frontier Servers
Name: frontier-awstats
Version: 6.9
Release: 1.2
License: GPL
Group: System/Server
Source0: %{name}.tar.gz

Requires: perl-libwww-perl
Requires: frontier-squid >= 11:
Conflicts: awstats

%define frontieruser squid
%define squidconf /etc/squid/squidconf

%define cmsawstats frontier-awstats-6.9-1
%define cmsawstatstargz %{cmsawstats}.tgz

# Define relocatable directories without leading slash
%define usrsharedir usr/share
%define frontierascriptdir  %{usrsharedir}/frontier-awstats
%define datadir var/lib/%{name}
# etcdir is not relocatable
%define etcdir /etc/awstats

%define passwordFile %{etcdir}/password-file

%define sourceConfig \
	if [ -s %{squidconf} ]; then \
    	source %{squidconf} \
	fi \
	if [ -z ${FRONTIER_USER} ] ; then \
	    export FRONTIER_USER=%{frontieruser} \
	fi

BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Prefix: /

%description
Configuration and script files for monitoring frontier server through awstat.
The monitoring information are collected by the node frontier.cern.ch.
All the directories, except for %etc are relocatable
The %version signifies awstats version that this rpm is based on.
Frontier specific changes to the base awstats functionality has been added by cms,
for details: https://twiki.cern.ch/twiki/bin/view/CMS/AWStatsForCMSSquid

%prep
%setup -n %{name}

%build

%install
/bin/rm -rf %{buildroot}

mkdir -p %{buildroot}%{prefix}%{usrsharedir}
mkdir -p %{buildroot}%{etcdir}
mkdir -p %{buildroot}%{prefix}%{datadir}

pushd %{buildroot}%{prefix}%{usrsharedir}
wget http://frontier.cern.ch/dist/%{cmsawstatstargz}
tar -zxf %{cmsawstatstargz}
/bin/rm %{cmsawstatstargz}
/bin/mv %{cmsawstats}/awstats %{name}
# These are not used by this rpm because the rpm has its own too-heavily
#   modified versions.  Perhaps one day a patch could be kept instead.
/bin/rm %{cmsawstats}/squid_rotate.sh %{cmsawstats}/chkthread.sh
rmdir %{cmsawstats}
# this is installed in a different directory
install -m 644 %{name}/awstats.model.conf %{buildroot}%{etcdir}
/bin/rm -f %{name}/awstats.model.conf
ls -lt
popd

# Handling:
#	/etc/awstats/run_awstats.sh.proto
#	/etc/awstats/chkthread.sh.proto
#	/etc/awstats/squidmodifiedqueries.logrotate.proto
cp %{_builddir}/unproto.sh 					%{buildroot}%{prefix}/%{frontierascriptdir}
install -m 644 %{_builddir}%{etcdir}/*     		%{buildroot}%{etcdir}

%pre
%sourceConfig
# Fail if ${FRONTIER_USER} does not exist:
if ! getent passwd ${FRONTIER_USER} >/dev/null 2>&1 ; then
      echo "ERROR: Non existent ${FRONTIER_USER} account."
      echo "Exiting ..."
      exit 1
fi

%post
%sourceConfig
# TBD: Learn if I may avoid the need of: Correction: cause files of %{etcdir} not to be relocated
if [ ${RPM_INSTALL_PREFIX} != '/' ]; then # relocated
    # the stuff in etcdir is not to be relocated
    mkdir -p %{etcdir}
    /bin/mv ${RPM_INSTALL_PREFIX}%{etcdir}/* %{etcdir}
    # make sure RPM_INSTALL_PREFIX has a trailing slash
    case "$RPM_INSTALL_PREFIX" in
	*/);;
	*) RPM_INSTALL_PREFIX="$RPM_INSTALL_PREFIX/";;
    esac
fi

export ETC_DIR_=%{etcdir} # Not to be relocated
export AWSTATSSCRIPTS_DIR_=${RPM_INSTALL_PREFIX}%{frontierascriptdir}
export DATA_DIR_=${RPM_INSTALL_PREFIX}%{datadir}
export TOMCAT_DIR_=${RPM_INSTALL_PREFIX}%{usrsharedir}/frontier-tomcat/tomcat

# Creating and installing configuration file and run_awstats.sh, from templates
#

# unproto: create files out of their .prot files, using env vars to be replaced
replaceVars="AWSTATSSCRIPTS_DIR_ DATA_DIR_ ETC_DIR_ TOMCAT_DIR_"
UNPROTO_SCRIPT=${AWSTATSSCRIPTS_DIR_}/unproto.sh
${UNPROTO_SCRIPT} ${ETC_DIR_}/run_awstats.sh.proto 	0 744 ${replaceVars}
${UNPROTO_SCRIPT} ${ETC_DIR_}/chkthread.sh.proto 	0 744 ${replaceVars}
#Not to be removed, as long as squidmodifiedqueries.logrotate.proto runs once and again: /bin/rm ${UNPROTO_SCRIPT}

if [ ! -e %{passwordFile} ]; then
    > %{passwordFile}
fi
chmod 600 %{passwordFile}
chown -R ${FRONTIER_USER} ${ETC_DIR_} ${DATA_DIR_}

chown ${FRONTIER_USER} ${ETC_DIR_}/run_awstats.sh ${ETC_DIR_}/chkthread.sh

if [ -e /var/spool/cron/${FRONTIER_USER} ]; then
    # Removing lines from cron job, in case upgrading from previous release
    #  that had cron lines with %{name} in it, and before adding current
    #  lines in case the install prefix changed.
    sed -i -e '/^1,16,31,46.*\/'%{name}'/d' \
           -e '/^59 23.*\/'%{name}'/d' \
	   -e '/'`echo %{etcdir}/|sed 's,/,\\\\/,g'`'chkthread.log/d' \
			   /var/spool/cron/${FRONTIER_USER}
    if [ ! -s /var/spool/cron/${FRONTIER_USER} ]; then
      # remove if now empty
      rm -f /var/spool/cron/${FRONTIER_USER}
    fi
fi
if [ -d "$TOMCAT_DIR_" ]; then
    # add chkthread.sh lines to cron
    (
    echo "*/5 * * * * $ETC_DIR_/chkthread.sh >> $ETC_DIR_/chkthread.log 2>&1"
    echo "59 23 * * 6 mv $ETC_DIR_/chkthread.log $ETC_DIR_/chkthread.log.old" 
    ) >>/var/spool/cron/${FRONTIER_USER}
    chown ${FRONTIER_USER} /var/spool/cron/${FRONTIER_USER}
    chmod 400 /var/spool/cron/${FRONTIER_USER}
fi

# remove logdir from previous release, if any
LOG_DIR_OLD=${RPM_INSTALL_PREFIX}var/log/%{name}
if [ -d ${LOG_DIR_OLD} ]; then
    /bin/rm -r ${LOG_DIR_OLD}
fi

# remove awstats.conf from previous release, if any
/bin/rm -f %{etcdir}/awstats.conf

%preun
%sourceConfig

if [ $1 -eq 0 ]; then
  # rm the files that are extracted from *.proto files (since they do not appear under files)
  /bin/rm -f %{etcdir}/run_awstats.sh %{etcdir}/chkthread.sh
  /bin/rm -f %{etcdir}/squidmodifiedqueries.logrotate
  /bin/rm -f %{etcdir}/squidmodifiedqueries.logrotate.status
  if [ -f /var/spool/cron/${FRONTIER_USER} ]; then
    # remove the cron entries
    sed -i -e '/'`echo %{etcdir}/|sed 's,/,\\\\/,g'`'chkthread.log/d' \
			   /var/spool/cron/${FRONTIER_USER}
    if [ ! -s /var/spool/cron/${FRONTIER_USER} ]; then
      # remove if now empty
      rm -f /var/spool/cron/${FRONTIER_USER}
    fi
  fi

  # echo "Frontier awstats removed successfully"
fi

#%postun
#if [ $1 -eq 0 ]; then
#
#fi

%clean
%{__rm} -rf %{buildroot}

%files
%verify(not user group) %{prefix}%{datadir}/
%verify(not user group) %{prefix}%{frontierascriptdir}/
%verify(not user group) %config %{etcdir}/
